@@ -19,18 +19,22 @@ class DeviceNonWorkingHours(DataClassORJSONMixin):
     start_time: str = ""
     end_time: str = ""
 
+
 @dataclass
 class LampInfo(DataClassORJSONMixin):
     lamp_bright: int = 0
     manual_light: bool = False
     night_light: bool = False
 
+
 @dataclass
 class MowerInfo(DataClassORJSONMixin):
     blade_status: bool = False
     rain_detection: bool = False
     traversal_mode: int = 0
     turning_mode: int = 0
+    blade_mode: int = 0
+    blade_rpm: int = 0
     side_led: SideLight = field(default_factory=SideLight)
     collector_installation_status: bool = False
     model: str = ""
