@@ -7,12 +7,13 @@ from pymammotion.utility.device_type import DeviceType
 
 class AbstractMessage:
     seqs = AtomicInteger(0)
-    user_account: int = 1
+    user_account: int
 
     @abstractmethod
     def get_device_name(self) -> str:
         """Get device name."""
 
+    @abstractmethod
     def get_device_product_key(self) -> str:
         """Get device name."""
 
